@@ -1,10 +1,15 @@
 import json
+from typing import TYPE_CHECKING, Any, Dict, Optional, Set
+
 import requests
+from requests.auth import HTTPBasicAuth
+
+from stytch.api.decorator import throw_stytch_exception
 from stytch.version import __version__
 
-from typing import Dict, Set
+if TYPE_CHECKING:
+    from stytch.client import Client
 
-from .decorator import throw_stytch_exception
 
 def _validate_attributes(attributes: Dict[str, str]) -> Dict[str, str]:
     if not attributes:
@@ -18,17 +23,15 @@ def _validate_attributes(attributes: Dict[str, str]) -> Dict[str, str]:
 
     return default_attributes
 
+
 class Base:
-    def __init__(self, client):
-        self._requester_base = requests
+    def __init__(self, client: "Client") -> None:
         self.headers = {
-            'Content-Type': 'application/json',
-            'User-Agent': 'Stytch Python v{}'.format(__version__)
+            "Content-Type": "application/json",
+            "User-Agent": "Stytch Python v{}".format(__version__),
         }
         self.client = client
-        self.auth = requests.auth.HTTPBasicAuth(
-            self.client.project_id, self.client.secret
-        )
+        self.auth = HTTPBasicAuth(self.client.project_id, self.client.secret)
 
     def _validate_options(self, options: Dict[str, bool]) -> Dict[str, bool]:
         if not options:
@@ -36,9 +39,7 @@ class Base:
 
         default_options = {}
         if options.get("ip_match_required"):
-            default_options.update(
-                {"ip_match_required": options["ip_match_required"]}
-            )
+            default_options.update({"ip_match_required": options["ip_match_required"]})
         if options.get("user_agent_match_required"):
             default_options.update(
                 {"user_agent_match_required": options["user_agent_match_required"]}
@@ -52,21 +53,30 @@ class Base:
 
         return True
 
-    def get_url(self, arg: str):
+    def get_url(self, arg: str) -> str:
         return "{0}{1}".format(self.client.base_url, arg)
 
     @throw_stytch_exception
-    def _get(self, url: str, query_params: Dict = {}):
-        return self._requester_base.get(url, auth=self.auth, headers=self.headers, params=query_params)
+    def _get(
+        self, url: str, query_params: Optional[Dict[str, Any]] = None
+    ) -> requests.Response:
+        query_params = query_params or {}
+        return requests.get(
+            url, auth=self.auth, headers=self.headers, params=query_params
+        )
 
     @throw_stytch_exception
-    def _post(self, url: str, data: Dict):
-        return self._requester_base.post(url, auth=self.auth, headers=self.headers, data=json.dumps(data))
+    def _post(self, url: str, data: Dict[str, Any]) -> requests.Response:
+        return requests.post(
+            url, auth=self.auth, headers=self.headers, data=json.dumps(data)
+        )
 
     @throw_stytch_exception
-    def _put(self, url: str, data: Dict):
-        return self._requester_base.put(url, auth=self.auth, headers=self.headers, data=json.dumps(data))
+    def _put(self, url: str, data: Dict[str, Any]) -> requests.Response:
+        return requests.put(
+            url, auth=self.auth, headers=self.headers, data=json.dumps(data)
+        )
 
     @throw_stytch_exception
-    def _delete(self, url: str):
-        return self._requester_base.delete(url, auth=self.auth, headers=self.headers)
+    def _delete(self, url: str) -> requests.Response:
+        return requests.delete(url, auth=self.auth, headers=self.headers)
